@@ -33,7 +33,7 @@ my $has_cycle      = eval "use Devel::Cycle; 1;";
 use Devel::Peek;
 
 use vars qw($VERSION);
-$VERSION = '1.52';
+$VERSION = '1.53';
 
 use constant DEBUG => $ENV{PERLBAL_DEBUG} || 0;
 use constant DEBUG_OBJ => $ENV{PERLBAL_DEBUG_OBJ} || 0;
@@ -262,7 +262,8 @@ sub run_manage_command {
     if ($basecmd eq "crash") { die "Intentional crash." };
 
     no strict 'refs';
-    if (my $handler = *{"MANAGE_$basecmd"}{CODE}) {
+    my $handler;
+    if ($Perlbal::{"MANAGE_$basecmd"} && ($handler = *{"MANAGE_$basecmd"}{CODE})) {
         my $rv = eval { $handler->($mc); };
         return $mc->err($@) if $@;
         return $rv;
