@@ -161,6 +161,12 @@ sub ipport {
     return $self->{ipport};
 }
 
+# called to tell backend that the client has gone on to do something else now.
+sub forget_client {
+    my Perlbal::BackendHTTP $self = $_[0];
+    $self->{client} = undef;
+}
+
 # called by service when it's got a client for us, or by ourselves
 # when we asked for a client.
 # returns true if client assignment was accepted.
@@ -435,6 +441,7 @@ sub handle_response { # : void
         # also update the response code, in case of 206 partial content
         my $rescode = $hd->response_code;
         $thd->code($rescode) if $rescode == 206 || $rescode == 416;
+        $thd->code(200) if $thd->response_code == 204;  # upgrade HTTP No Content (204) to 200 OK.
     }
 
     print "  writing response headers to client\n" if Perlbal::DEBUG >= 3;
